@@ -7,9 +7,8 @@ use Log::Any::Adapter::Util 'numeric_level';
 use Log::Any 1.03;
 use Log::Any::Adapter::Daemontools::Config;
 
-our $VERSION= '0.101';
-
 # ABSTRACT: Logging adapter suitable for use in a Daemontools-style logging chain
+our $VERSION = '0.102'; # VERSION
 
 
 our $global_config;
@@ -183,7 +182,7 @@ Log::Any::Adapter::Daemontools - Logging adapter suitable for use in a Daemontoo
 
 =head1 VERSION
 
-version 0.101
+version 0.102
 
 =head1 SYNOPSIS
 
@@ -277,8 +276,10 @@ configuration in many ways without having to re-attach the adapters.
 =item C<--verbose> / C<--quiet> / C<$ENV{DEBUG}>
 
 My scripts usually end up with a chunk of boilerplate in the option processing
-to raise or lower the log level.  This module provides an option to get you
-common UNIX behavior in as little as 7 characters :-)
+to raise or lower the log level.  This module replaces that with a simple
+
+  -init => { argv => 'consume', env => 1 };
+
 It's flexible enough to give you many other common varieties, or you can ignore
 it because it isn't enabled by default.
 
@@ -293,7 +294,7 @@ and allows full customization with coderefs.
 
 I often forget to C< $|= 1 >, and then wonder why my log messages don't match
 what the program is currently doing.  This module turns on autoflush if
-'output' is a file handle.  (but if output is a coderef or other object, it's
+C<output> is a file handle.  (but if output is a coderef or other object, it's
 still up to you)
 
 =back
@@ -348,7 +349,7 @@ Not actually an attribute!  If you pass this to the Daemontools adapter,
 the first time an instance of the Adapter is created it will call ->init on
 the adapter's configuration.  This allows you to squeeze things onto one line.
 
-The more proper way to write the above example is:
+The more verbose way to write the above example is:
 
   use Log::Any::Adapter 'Daemontools';
   Log::Any::Adapter::Daemontools->global_config->init( ... );
@@ -374,7 +375,7 @@ Michael Conrad <mike@nrdvana.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Michael Conrad.
+This software is copyright (c) 2019 by Michael Conrad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
